<?php

use Illuminate\Support\Facades\Auth;
/*use DeviceDetector\Parser\Client\Browser;*/
use DeviceDetector\DeviceDetector;
use DeviceDetector\Parser\Device\DeviceParserAbstract;
use Illuminate\Support\Facades\Hash;
use App\Models\RoleUser;

/**
 * @param $status
 * @param $statusCode
 * @param $message
 * @param array $errors
 * @param array $result
 * @return \Illuminate\Http\JsonResponse
 */
function apiResponse($status, $statusCode, $message, $errors = [], $result = [], $htmlResponse = "")
{
    $response = ['success' => $status, 'status' => $statusCode];

    if ($message != "") {
        $response['message'] = $message;
    }

    if (count($errors) > 0 && is_array($errors))  {
        $response['errors'] = $errors;
    }

    if (count($result) > 0 && is_array($result)) {
        $response['result'] = $result;
    }

    if ($htmlResponse != "") {
        $response['html_response'] = $htmlResponse;
    }

    return response()->json($response, $statusCode);
}

function validationResponse($status, $statusCode, $message, $errors = [])
{
    $response = ['success' => $status, 'status' => $statusCode];

    if ($message != "") {
        $response['message'] = $message;
    }
    
    if (!empty($errors))  {
        $response['errors'] = errorMessages($errors);
    }       

    return response()->json($response, $statusCode);
}


//For App
function apiResponseApp($status, $statusCode, $message, $errors = [], $data = [])
{
    $response = ['success' => $status, 'status' => $statusCode];
    
    if ($message != "") {
        $response['message']['success'] = $message;
    }

    if (count($errors) > 0) {
        $response['message']['errors'] = $errors;
    }

    if (count($data) > 0) {
        $response['message']['data'] = $data;
    }
    return response()->json($response);
}


/**
 * @param null $path
 * @param null $string
 * @return null
 */
function lang($path = null, $string = null)
{
    $lang = $path;
    if (trim($path) != '' && trim($string) == '') {
        $lang = \Lang::get($path);
    } elseif (trim($path) != '' && trim($string) != '') {
        $lang = \Lang::get($path, ['attribute' => $string]);
    }
    return $lang;
}


/**
 * @param array $errors
 * @return array
 */
function errorMessages($errors = [])
{
    $error = [];
    foreach($errors->toArray() as $key => $value) {
        foreach($value as $messages) {
            $error[$key] = $messages;
        }
    }
    return $error;
}

function convertToLocal($utcDate, $format = 'd-m-Y h:i A')
{
    // $currentTimezone = getCompanySettings('timezone');
    // $dateFormat = ($format != "") ? $format : getCompanySettings('datetime_format');

    $currentTimezone = 'Asia/Kolkata';
    $dateFormat = $format;

    if($currentTimezone !='') {
        $date = new \DateTime($utcDate, new DateTimeZone('UTC'));
        $date->setTimezone(new DateTimeZone($currentTimezone));
        return $date->format($dateFormat);
    } else {
        $date = new \DateTime($utcDate, new DateTimeZone('UTC'));
        return $date->format($dateFormat);
    }
}
/**
 * @param string $localDate
 * @param string $format
 * @return bool|string
 */
function convertToUtc($localDate = null, $format = null)
{
    //$currentTimezone = getCompanySettings('timezone');
    //$currentTimezone = 'America/Los_Angeles';
    $currentTimezone = 'UTC';    
    $format = ($format == "") ? 'Y-m-d H:i:s' : $format;
    $localDate = ($localDate == "") ? date('Y-m-d H:i:s') : $localDate;
    $date = new \DateTime($localDate, new DateTimeZone($currentTimezone));
    $date->setTimezone(new DateTimeZone('UTC'));
    return $date->format($format);
}

/**
 * @param bool $withTime
 * @return bool|string
 */
function currentDate($withTime = false)
{
    $date = date('Y-m-d H:i:s');
    if (!$withTime) {
        $date = date('Y-m-d');
    }
    return $date;
}


/**
 * Method is used to convert date to
 * specified format
 *
 * @param string $format
 * @param date $date
 *
 * @return Response|String
 */
function dateFormat($format, $date)
{
    if (trim($date) != '') {
        if (trim($date) == '0000-00-00' || trim($date) == '0000-00-00 00:00') {
            return null;
        } else {
            return date($format, strtotime($date));
        }
    }
    return $date;
}


/**
 * @return bool
 */
function isSystemAdmin()
{
    return (\Auth::user()->id == 1) ? true : false;
}

/**
 * @return null
 */
function authUserId() {
    $id = null;
    if (\Auth::check()) {
        $id = \Auth::user()->id;
    }
    return $id;
}

function authUserName() {

    $username = '';
    if (\Auth::check()) {
        $username =  ucwords(\Auth::user()->name);
    }
    return $username;    
}

function authUser()
{
    $user = null;
    if (\Auth::check()) {
        $user = \Auth::user();
    }
    return $user;
}

/**
 * @param $arr
 * @return mixed
 */
function arrayFilter($arr)
{
    foreach($arr as $key => $value)
    {
        if($value == '' || $value == null)
        {
            unset($arr[$key]);
        }
    }
    return $arr;
}

/**
 * Method is used to return string in lower, upper or ucfirst.
 *
 * @param string $string
 * @param string $type L -> lower, U -> upper, UC -> upper character first
 * @return Response
 */
function string_manip($string = null, $type = 'L')
{
    switch ($type) {
        case 'U':
            return strtoupper($string);
            break;
        case 'UC':
            return ucfirst($string);
            break;
        case 'UCW':
            return ucwords($string);
            break;
        default:
            return strtolower($string);
            break;
    }
}

/**
 * Trim whitespace from inputs
 *
 * @param Request $request
 * @return bool
 */
function trimInputs(Request $request)
{
    $inputs = $request->all();
    array_walk_recursive($inputs, function (&$value) {
        $value = trim($value);
    });
    $request->merge($inputs);
    return true;
}


/**
 * @param null $month
 * @param null $tillCurrentMonth
 * @return array
 */
function getMonths($month = null, $tillCurrentMonth = null)
{
    $months = [
        1	=>	'January',
        2	=>	'February',
        3	=>	'March',
        4	=>	'April',
        5	=>	'May',
        6	=>	'June',
        7	=>	'July',
        8	=>	'August',
        9	=>	'September',
        10	=>	'October',
        11	=>	'October',
        12	=>	'December'
    ];

    if ($month != "") {
        return $months[$month];
    }
    return ['' => '-Select Month-'] + $months;
}


/**
 * @param $start
 * @param $end
 * @return array
 */
function getYear($start, $end)
{
    $years = [];
    for($i =$start; $i <=$end; $i++) {
        $years[$i] = $i;
    }
    return ['' => '-Select Year-'] + $years;

}

/**
 * @param null $reportType
 * @param null $skipDay
 * @return int
 * @internal param $action
 */
function getReportType($reportType = null)
{
    $reportArray = [
        1	=>	'Day',
        2	=>	'Month',
        3	=>	'Year',
    ];

    if ($reportType != "") {
        return $reportArray[$reportType];
    }
    return $reportArray;
}

function sessionID()
{
    $sessionID = null;
    if (\Session::getId()) {
        $sessionID = \Session::getId();
    }
    return $sessionID;
}

function isSerialized($str) {
    return ($str == serialize(false) || @unserialize($str) !== false);
}


function generateUniqueId()
{   
    //returns 4 characters long unique id 
    return (string) mt_rand(1000, 9999);
}

function deviceDetect($user_agent){
    // Get the User-Agent string from the request
    $userAgent = $user_agent;
    // Initialize DeviceDetector
    $dd = new DeviceDetector($userAgent);

    // Parse the user agent
    $dd->parse();
     // Get client information
    $clientInfo = $dd->getClient(); // returns browser, feed reader, mobile app, etc.
    $osInfo = $dd->getOs(); // returns the operating system
    $device = $dd->getDevice(); // returns device type
    $brand = $dd->getBrand(); // returns device brand
    $model = $dd->getModel(); // returns device model

    // Check if the user agent is a bot
    if ($dd->isBot()) {
        $botInfo = $dd->getBot();
        return response()->json([
            'is_bot' => true,
            'bot_info' => $botInfo,
        ]);
    }

    /*dd(response()->json([
        'is_bot' => false,
        'client_info' => $clientInfo,
        'os_info' => $osInfo,
        'device' => $device,
        'brand' => $brand,
        'model' => $model,
    ]);*/

    // Return the device information as JSON
    return response()->json([
        'is_bot' => false,
        'client_info' => $clientInfo,
        'os_info' => $osInfo,
        'device' => $device,
        'brand' => $brand,
        'model' => $model,
    ]);
   
}


function filterSpecialContent($content){

    $htmlContent = '';
   /* $content = "## Business Challenges: Stock Management in the Hand Tool Industry
    fsadfasfdasfd
    fsadfasfdasfdsafasf
    ## fasdf";*/
    $entityContent = htmlentities($content);
    /* $pattern = '/##(.*?)\n/s';
    $pattern = '/\#\#/';
    dd(preg_match($pattern, $html, $matches);
    */
    //dd($entityContent);
    $explodeContent = explode("\n", $entityContent);
    $doubleHashPattern = '/\#\#/';
    $double_matched_elements = preg_grep($doubleHashPattern, $explodeContent);

    $doubleAsterikPattern = '/\*\*/';
    $asterik_matched_elements = preg_grep($doubleAsterikPattern, $explodeContent);

    //dd($entityContent);
    
    $originalContent = $entityContent;
    //Double Hash & Triple Hash Replacement
    if(!empty($double_matched_elements)){
        //dd($double_matched_elements);        
        foreach($double_matched_elements as $k => $v){
            $original = $v;
            $hash = '#';
            // Use substr_count to count occurrences of the character
            $characterCount = substr_count($v, $hash);
            if($characterCount === 2 ){
                $content_double_remove = str_replace("##", "", $v);
                $content_h2 = '<h2>'.$content_double_remove.'</h2>'; 
                $originalContent = str_replace($original, $content_h2, $originalContent);
            }

            if($characterCount === 3 ){
                $content_three_remove = str_replace("###", "", $v);
                $content_h3 = '<h3>'.$content_three_remove.'</h3>'; 
                $originalContent = str_replace($original, $content_h3, $originalContent);
            }

            //dd($content_update);
            $content  = $originalContent;
        }        
         

    }

    //Double Asterik Replacement
    if(!empty($asterik_matched_elements)){
        //dd($asterik_matched_elements);        
        foreach($asterik_matched_elements as $n => $t){
            $original = $t;
            $asterik = '*';
            // Use substr_count to count occurrences of the character
            $asterikCount = substr_count($t, $asterik);

            //dd($asterikCount);
            if($asterikCount === 4 ){
                $double_asterik = '**';
                //$text = "sdfsd fsafsffsd f ** hello world testing ** sdf ** Test My **asfsa *sfa* fsajf laskfjlasfs*";
                //$pattern = '/^[*].*\d$/';
                //$pattern = '/\**[^*]+*\*/';
                $pattern = '/\*\*([^\*]+)\*\*/';
                preg_match_all($pattern, $t, $matches);
                //$matchesss = preg_match($pattern, $text, $matches);
                if(!empty($matches) && array_key_exists(0, $matches)){
                    if(!empty($matches[0])){
                        //dd($matches[0]);
                        foreach($matches[0] as $g => $e){  
                            $asterik_original = $e;          

                            //print_r($asterik_original);                 
                             $asterik_double_remove = str_replace("**", "", $e);
                             $asterik_content_strong = '<strong>'.$asterik_double_remove.'</strong>';                             

                             $originalContent = str_replace($asterik_original, $asterik_content_strong, $originalContent);

                             //print_r($originalContent);

                        }
                    }
                   
                }
                
            }            

            //dd($originalContent);            
            
            //dd($content_update);
            $content  = $originalContent;
        }

        //dd($content);             
         

    }

    return nl2br($content);
}

function generateHashId(){
    return md5(microtime());
}

function getRole($user_id){
    $role = (new RoleUser)->where('user_id', $user_id)->first(['role_id']);
    return $role;
}