<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\ClientInfo;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
//use Illuminate\Http\Response;
use Illuminate\Http\JsonResponse;
use Exception;
use App\Models\CaseService;

class AuthController extends Controller
{
    public function login(Request $request, $case_id = "")
    {
        //dd(Auth::check());
        if ($request->isMethod('get')) {
            return view('frontend.login', compact('case_id'));
        } else {

            $inputs = $request->all();
            unset($inputs['_token']);
            $validator = (new User)->validateLogin($inputs);
                
            if ($validator->fails()) {
                //$validator->errors()
               //dd($validator->errors());
                return redirect()->route('login')
                    ->withInput()
                    ->withErrors($validator);
            }  

            unset($inputs['remember']);

            $case_id = $inputs['case_id'];
            unset($inputs['case_id']);            
            
            //dd($inputs);

            $inputs = $inputs + [
                            'status' => 'active'
                        ];  

            if (Auth::attempt($inputs, $request->filled('remember'))) {

                $caseExist = (new CaseService)->checkCaseUserExist($case_id);

                //Case update with user id
                if(!empty($case_id) && !empty($caseExist)){

                    $user_data = ['user_id' => authUserId()];
                    (new CaseService)->updateCases($user_data, $case_id);
                }

                return redirect()->intended('dashboard');
                
            } else {

                return redirect()->route('login')->withErrors(['error' => 'Invalid Credentials']);
            }
        }
    }

    public function register(Request $request, $case_id = "")
    {
        if ($request->isMethod('get')) {
            return view('frontend.register', compact('case_id'));
        } else {

            try{

                $inputs = $request->all();
                unset($inputs['_token']);

                $case_id = $inputs['case_id'];
                unset($inputs['case_id']);                

                //dd($inputs);

                $validator = (new User)->validate($inputs);
                
                if ($validator->fails()) {
                    //$validator->errors()
                   //dd($validator->errors());
                    return redirect()->route('register')
                        ->withInput()
                        ->withErrors($validator);
                } 

                $browserParser = deviceDetect($request->header('User-Agent'));

                $encryptedPassword = Hash::make($inputs['password']);
                unset($inputs['password']);
                
                $data = $inputs + [
                        'company_id' => 1,
                        'password' => $encryptedPassword,
                        'status' => 'active',
                        'last_login' => currentDate(true),
                        'admin_approval' => 1,
                        'headers' => $browserParser->getContent(),
                        'created_at' => currentDate(true)
                    ]; 

                $register = User::create($data);    
                //$register = true;

                if ($register) {

                    $caseExist = [];
                    $clientInfo = [];
                    if(!empty($case_id)){
                        $caseExist = (new CaseService)->checkCaseUserExist($case_id);

                        $clientInfo = (new ClientInfo)->getClientInfoByCaseID($case_id);
                    } 

                    //Case update with user id
                    if(!empty($case_id) && !empty($register->id) && !empty($caseExist)){
                        $user_data = ['user_id' => $register->id];
                        (new CaseService)->updateCases($user_data, $case_id);
                    }

                    //Register table updation with client info first time registeration 
                    if(!empty($clientInfo) && !empty($register->id)){

                        $clientDetails = [
                            'salutation' => $clientInfo->saluation,
                            'first_name' => $clientInfo->first_name,
                            'last_name' => $clientInfo->last_name,
                            'dob' => $clientInfo->dob,
                            'postal_code' => $clientInfo->postal_code,
                            'address' => $clientInfo->address,
                            'mobile' => $clientInfo->mobile_no,
                            'communicate_email' => $clientInfo->email,
                            'updated_at' => currentDate(true)
                        ];

                        (new User)->updateProfile($clientDetails, $register->id);
                    }

                    return redirect()->route('login');
                }

                throw new \Exception(lang('common.something_wrong'));


            }catch(\Exception $e){
                return redirect()->route('register')->with('error', lang('messages.server_error'.$e->getMessage())); 
            }
            
        }
    }

    public function accountSetup(Request $request, $flow_id = "")
    {
        if ($request->isMethod('get')) {
            return view('frontend.account_setup', compact('flow_id'));
        } else {

            try{

                $inputs = $request->all();
                unset($inputs['_token']);

                if(array_key_exists('flow_id', $inputs)  && !empty($inputs['flow_id'])){
                    $flow_id = $inputs['flow_id'];
                    unset($inputs['flow_id']);  
                }                              

                //dd($inputs);

                $validator = (new User)->validateConfirm($inputs);
                
                if ($validator->fails()) {
                    //$validator->errors()
                    //dd($validator->errors());
                    return redirect()->route('account-setup', ['flow_id' => $flow_id])
                        ->withInput()
                        ->withErrors($validator);
                } 

                $browserParser = deviceDetect($request->header('User-Agent'));

                $encryptedPassword = Hash::make($inputs['password']);
                unset($inputs['password']);
                
                $data = $inputs + [
                        'name' => "Guest",
                        'company_id' => 1,
                        'password' => $encryptedPassword,
                        'status' => 'active',
                        'last_login' => currentDate(true),
                        'admin_approval' => 1,
                        'headers' => $browserParser->getContent(),
                        'created_at' => currentDate(true)
                    ]; 

                $register = User::create($data);   

                return redirect()->route('login');

                //$register = true;

                if ($register) {

                    $caseExist = [];
                    $clientInfo = [];
                    if(!empty($case_id)){
                        $caseExist = (new CaseService)->checkCaseUserExist($case_id);

                        $clientInfo = (new ClientInfo)->getClientInfoByCaseID($case_id);
                    } 

                    //Case update with user id
                    if(!empty($case_id) && !empty($register->id) && !empty($caseExist)){
                        $user_data = ['user_id' => $register->id];
                        (new CaseService)->updateCases($user_data, $case_id);
                    }

                    //Register table updation with client info first time registeration 
                    if(!empty($clientInfo) && !empty($register->id)){

                        $clientDetails = [
                            'salutation' => $clientInfo->saluation,
                            'first_name' => $clientInfo->first_name,
                            'last_name' => $clientInfo->last_name,
                            'dob' => $clientInfo->dob,
                            'postal_code' => $clientInfo->postal_code,
                            'address' => $clientInfo->address,
                            'mobile' => $clientInfo->mobile_no,
                            'communicate_email' => $clientInfo->email,
                            'updated_at' => currentDate(true)
                        ];

                        (new User)->updateProfile($clientDetails, $register->id);
                    }

                    return redirect()->route('login');
                }

                throw new \Exception(lang('common.something_wrong'));


            }catch(\Exception $e){
                return redirect()->route('account-setup', ['flow_id' => $flow_id])->with('error', lang('messages.server_error')); 
            }
            
        }
    }

    public function logout()
    {
        Auth::logout();
        return redirect()->route('home');        
    }
}
