<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\BusinessInfo;
use App\Models\BusinessService;
use App\Models\CaseService;
use App\Models\CompanyInfo;
use App\Models\ProjectInfo;
use App\Models\QgCase;
use App\Models\QgProjectScope;
use App\Models\QgService;
use Illuminate\Http\Request;
use Spatie\SimpleExcel\SimpleExcelWriter;
use Illuminate\Support\Facades\Auth;
use DateTime;

class CaseController extends Controller
{
    public function index()
    {
        if (Auth::user()->roles == 1) {
            $cases = QgCase::orderBy('id', 'desc')->paginate(10);
            return view('backend.admin.cases.cases')->with(['cases' => $cases]);
        } else if (Auth::user()->roles == 2) {
            $cases = QgCase::orderBy('id', 'desc')->paginate(10);
            return view('backend.team.cases.cases')->with(['cases' => $cases]);
        } else {
            $cases = QgCase::orderBy('id', 'desc')->paginate(10);
            return view('backend.staff.cases.cases')->with(['cases' => $cases]);
        }
    }

    public function getCase($id)
    {
        if (Auth::user()->roles == 1) {
            $getCase = QgCase::with('notes.user')->where('case_id', $id)->get()->toArray();

            if(!empty($getCase[0]) && array_key_exists('0', $getCase)){
                if(!empty($getCase[0]['address'])){
                    $address = json_decode($getCase[0]['address'], true);

                    $getCase[0]['address1'] = '';
                    if($address['address1']){
                        $getCase[0]['address1'] = $address['address1'];
                    }

                    $getCase[0]['address2'] = '';
                    if($address['address2']){
                        $getCase[0]['address2'] = $address['address2'];
                    }

                    $getCase[0]['town_or_city'] = '';
                    if($address['town_or_city']){
                        $getCase[0]['town_or_city'] = $address['town_or_city'];
                    }

                    $getCase[0]['country'] = '';
                    if($address['country']){
                        $getCase[0]['country'] = $address['country'];
                    }
                    
                    //dd($getCase);
                }
            }
            //dd($getCase[0]);
            return view('backend.admin.cases.view_case')->with(['case' => $getCase[0]]);
        } else if (Auth::user()->roles == 2) {
            $getCase = QgCase::with(['notes' => function ($query) {
                $query->where('user_id', Auth::user()->id);
            }])->where('case_id', $id)->get()->toArray();
            return view('backend.team.cases.view_case')->with(['case' => $getCase[0]]);
        } else {
            $getCase = QgCase::with('notes')->where('case_id', $id)->get()->toArray();
            return view('backend.staff.cases.view_case')->with(['case' => $getCase[0]]);
        }
    }

    public function filterCases(Request $request)
    {
        if (Auth::user()->roles == 1) {
            $cases = QgCase::where(function ($query) use ($request) {
                $query->where('email', 'like', '%' . $request->email . '%');
                $query->where('mobile_no', 'like', '%' . $request->mobile . '%');
                if ($request->date != null) {
                    $query->whereRaw('DATE_FORMAT(created_at, "%Y-%m-%d") like ?', ['%' . $request->date . '%']);
                }
            })->paginate(10)->appends($request->all());

            return view('backend.admin.cases.cases')->with(['input' => ['email' => $request->email, 'mobile' => $request->mobile, 'date' => $request->date], 'cases' => $cases]);
        } else if (Auth::user()->roles == 2) {
            $cases = QgCase::where(function ($query) use ($request) {
                $query->where('email', 'like', '%' . $request->email . '%');
                $query->where('mobile_no', 'like', '%' . $request->mobile . '%');
                if ($request->date != null) {
                    $query->whereRaw('DATE_FORMAT(created_at, "%Y-%m-%d") like ?', ['%' . $request->date . '%']);
                }
            })->paginate(10)->appends($request->all());

            return view('backend.team.cases.cases')->with(['input' => ['email' => $request->email, 'mobile' => $request->mobile, 'date' => $request->date], 'cases' => $cases]);
        } else {
            $cases = QgCase::where(function ($query) use ($request) {
                $query->where('email', 'like', '%' . $request->email . '%');
                $query->where('mobile_no', 'like', '%' . $request->mobile . '%');
                if ($request->date != null) {
                    $query->whereRaw('DATE_FORMAT(created_at, "%Y-%m-%d") like ?', ['%' . $request->date . '%']);
                }
            })->paginate(10)->appends($request->all());

            return view('backend.staff.cases.cases')->with(['input' => ['email' => $request->email, 'mobile' => $request->mobile, 'date' => $request->date], 'cases' => $cases]);
        }
    }

    public function searchCases(Request $request)
    {
        if (Auth::user()->roles == 1) {
            $cases = QgCase::where(function ($query) use ($request) {
                $query->orWhere('case_id', 'like', '%' . $request->q . '%');
                $query->orWhere('first_name', 'like', '%' . $request->q . '%');
                $query->orWhere('last_name', 'like', '%' . $request->q . '%');
                $query->orWhereRaw('CONCAT(first_name, " ", last_name) like ?', ['%' . $request->q . '%']);
            })->paginate(10);
            return view('backend.admin.cases.cases')->with(['query' => $request->q, 'cases' => $cases]);
        } else if (Auth::user()->roles == 2) {
            $cases = QgCase::where(function ($query) use ($request) {
                $query->orWhere('case_id', 'like', '%' . $request->q . '%');
                $query->orWhere('first_name', 'like', '%' . $request->q . '%');
                $query->orWhere('last_name', 'like', '%' . $request->q . '%');
                $query->orWhereRaw('CONCAT(first_name, " ", last_name) like ?', ['%' . $request->q . '%']);
            })->paginate(10);
            return view('backend.team.cases.cases')->with(['query' => $request->q, 'cases' => $cases]);
        } else {
            $cases = QgCase::where(function ($query) use ($request) {
                $query->orWhere('case_id', 'like', '%' . $request->q . '%');
                $query->orWhere('first_name', 'like', '%' . $request->q . '%');
                $query->orWhere('last_name', 'like', '%' . $request->q . '%');
                $query->orWhereRaw('CONCAT(first_name, " ", last_name) like ?', ['%' . $request->q . '%']);
            })->paginate(10);
            return view('backend.staff.cases.cases')->with(['query' => $request->q, 'cases' => $cases]);
        }
    }

    public function export()
    {
        $lastURL = parse_url(url()->previous());

        if (Auth::user()->roles == 1) {
            if ($lastURL['path'] == '/admin/search_cases') {
                parse_str($lastURL['query'], $queryParams);

                $cases = QgCase::where(function ($query) use ($queryParams) {
                    $query->orWhere('case_id', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhere('first_name', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhere('last_name', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhereRaw('CONCAT(first_name, " ", last_name) like ?', ['%' . $queryParams['q'] . '%']);
                })->get()->toArray();
            } else if ($lastURL['path'] == '/admin/filter_cases') {
                parse_str($lastURL['query'], $queryParams);

                $cases = QgCase::where(function ($query) use ($queryParams) {
                    $query->where('email', 'like', '%' . $queryParams['email'] . '%');
                    $query->where('mobile_no', 'like', '%' . $queryParams['mobile'] . '%');
                    if ($queryParams['date'] != null) {
                        $query->whereRaw('DATE_FORMAT(created_at, "%Y-%m-%d") like ?', ['%' . $queryParams['date'] . '%']);
                    }
                })->get()->toArray();
            } else {
                $cases = QgCase::orderBy('id', 'desc')->get()->toArray();
            }
        } else if (Auth::user()->roles == 2) {
            if ($lastURL['path'] == '/user/search_cases') {
                parse_str($lastURL['query'], $queryParams);

                $cases = QgCase::where(function ($query) use ($queryParams) {
                    $query->orWhere('case_id', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhere('first_name', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhere('last_name', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhereRaw('CONCAT(first_name, " ", last_name) like ?', ['%' . $queryParams['q'] . '%']);
                })->get()->toArray();
            } else if ($lastURL['path'] == '/user/filter_cases') {
                parse_str($lastURL['query'], $queryParams);

                $cases = QgCase::where(function ($query) use ($queryParams) {
                    $query->where('email', 'like', '%' . $queryParams['email'] . '%');
                    $query->where('mobile_no', 'like', '%' . $queryParams['mobile'] . '%');
                    if ($queryParams['date'] != null) {
                        $query->whereRaw('DATE_FORMAT(created_at, "%Y-%m-%d") like ?', ['%' . $queryParams['date'] . '%']);
                    }
                })->get()->toArray();
            }
        } else {
            if ($lastURL['path'] == '/staff/search_cases') {
                parse_str($lastURL['query'], $queryParams);

                $cases = QgCase::where(function ($query) use ($queryParams) {
                    $query->orWhere('case_id', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhere('first_name', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhere('last_name', 'like', '%' . $queryParams['q'] . '%');
                    $query->orWhereRaw('CONCAT(first_name, " ", last_name) like ?', ['%' . $queryParams['q'] . '%']);
                })->get()->toArray();
            } else if ($lastURL['path'] == '/staff/filter_cases') {
                parse_str($lastURL['query'], $queryParams);

                $cases = QgCase::where(function ($query) use ($queryParams) {
                    $query->where('email', 'like', '%' . $queryParams['email'] . '%');
                    $query->where('mobile_no', 'like', '%' . $queryParams['mobile'] . '%');
                    if ($queryParams['date'] != null) {
                        $query->whereRaw('DATE_FORMAT(created_at, "%Y-%m-%d") like ?', ['%' . $queryParams['date'] . '%']);
                    }
                })->get()->toArray();
            }
        }

        $data = [];

        foreach ($cases as $case) {
            $data[] = [
                'Case ID' => $case['case_id'],
                'Name' => $case['first_name'] . ' ' . $case['last_name'],
                'DOB' => $case['dob'],
                'Email' => $case['email'],
                'Mobile' => $case['mobile_no']
            ];
        }

        return SimpleExcelWriter::streamDownload('cases' . now() . '.xlsx')
            ->addRows($data)->toBrowser();
    }

    public function getProjectScope($id)
    {
        $getCase = QgCase::with('notes')->where('case_id', $id)->get()->toArray();


        if(!empty($getCase[0]) && array_key_exists('0', $getCase)){
            if(!empty($getCase[0]['address'])){
                $address = json_decode($getCase[0]['address'], true);
                
                $getCase[0]['address1'] = '';
                if($address['address1']){
                    $getCase[0]['address1'] = $address['address1'];
                }
                
                $getCase[0]['address2'] = '';
                if($address['address2']){
                    $getCase[0]['address2'] = $address['address2'];
                }
                
                $getCase[0]['town_or_city'] = '';
                if($address['town_or_city']){
                    $getCase[0]['town_or_city'] = $address['town_or_city'];
                }
                
                $getCase[0]['country'] = '';
                if($address['country']){
                    $getCase[0]['country'] = $address['country'];
                }
                
                //dd($getCase);
            }
        }

        $getServices = QgService::all()->toArray();

        $project_scope = QgProjectScope::where('case_id', $id)->get()->toArray();

        $getServices = BusinessService::with('services')->get()->toArray();
        //dd($getServices);
        $projectScope = QgProjectScope::where('case_id', $id)->get()->toArray();

        $scopeData = [];

        foreach ($getServices as $service) {

            $key = '';
            if (empty($service['exist_service'])) {
                // dump($service['services']['key']);
                if(!empty($service['services']['key'])){
                    $key = $service['services']['key'];
                }
                
            } else {
                if(!empty($service['services']['alt_key'])){
                    $key = $service['services']['alt_key'];
                }
            }

            foreach ($projectScope as $scope) {

                if (isSerialized($scope['business_scope']) || true) {

                    $getScope = (array)unserialize($scope['business_scope']);

                    if (array_key_exists('bd_expanded', $getScope)) {
                        $scopeData['bd_expanded'] = $getScope['bd_expanded'];
                    }

                    if (array_key_exists('bc_expanded', $getScope)) {
                        $scopeData['bc_expanded'] = $getScope['bc_expanded'];
                    }

                    if (array_key_exists('key', $getScope)) {
                        // dump($getScope['key'] . ' - ' . $key);
                        if ($getScope['key'] == $key) {
                            if (array_key_exists('description_expanded', $getScope)) {
                                $scopeData[$key]['description_expanded'] = $getScope['description_expanded'];
                            } else {
                                $scopeData[$key][$getScope['question_id']] = $getScope;
                            }
                        }
                    }
                } else {
                    continue;
                }
            }
        }

        if (Auth::user()->roles == 1) {
            return view('backend.admin.project_scope.project_scope')->with(['case' => $getCase[0], 'getServices' => $getServices, 'projectScope' => $scopeData]);
        } else if (Auth::user()->roles == 2) {
            return view('backend.team.project_scope.project_scope')->with(['case' => $getCase[0], 'getServices' => $getServices, 'projectScope' => $scopeData]);
        } else {
            return view('backend.staff.project_scope.project_scope')->with(['case' => $getCase[0], 'getServices' => $getServices, 'projectScope' => $scopeData]);
        }
    }

    public function getBusinessInfo($id)
    {
        $getCase = QgCase::with('notes')->where('case_id', $id)->get()->toArray();

        if(!empty($getCase[0]) && array_key_exists('0', $getCase)){
            if(!empty($getCase[0]['address'])){
                $address = json_decode($getCase[0]['address'], true);

                $getCase[0]['address1'] = '';
                if($address['address1']){
                    $getCase[0]['address1'] = $address['address1'];
                }

                $getCase[0]['address2'] = '';
                if($address['address2']){
                    $getCase[0]['address2'] = $address['address2'];
                }

                $getCase[0]['town_or_city'] = '';
                if($address['town_or_city']){
                    $getCase[0]['town_or_city'] = $address['town_or_city'];
                }

                $getCase[0]['country'] = '';
                if($address['country']){
                    $getCase[0]['country'] = $address['country'];
                }
                
                //dd($getCase);
            }
        }

        $getBusinessInfo = [];

        $getBusinessInfo['basic_info'] = BusinessInfo::where('case_id', $id)->get()->toArray();

        if (count($getBusinessInfo['basic_info']) > 0) {

            $getServiceIds = CaseService::select('services_ids')->where('case_id', $getBusinessInfo['basic_info'][0]['case_id'])->get()->toArray();

            $explodedIds = explode(',', $getServiceIds[0]['services_ids']);

            $getBusinessInfo['services'] = BusinessService::with(['services', 'businessKeys' => function ($query) use ($getBusinessInfo) {
                $query->where('business_id', $getBusinessInfo['basic_info'][0]['id'])->where('case_id', $getBusinessInfo['basic_info'][0]['case_id']);
            }, 'businessDesigns' => function ($query) use ($getBusinessInfo) {
                $query->where('business_id', $getBusinessInfo['basic_info'][0]['id'])->where('case_id', $getBusinessInfo['basic_info'][0]['case_id']);
            }])->whereIn('service_id', $explodedIds)->where('business_id', $getBusinessInfo['basic_info'][0]['id'])->get()->toArray();

            if (Auth::user()->roles == 1) {
                return view('backend.admin.business.business_info')->with(['case' => $getCase[0], 'getBusinessInfo' => $getBusinessInfo]);
            } else if (Auth::user()->roles == 2) {
                return view('backend.team.business.business_info')->with(['case' => $getCase[0], 'getBusinessInfo' => $getBusinessInfo]);
            } else {
                return view('backend.staff.business.business_info')->with(['case' => $getCase[0], 'getBusinessInfo' => $getBusinessInfo]);
            }
        } else {
            if (Auth::user()->roles == 1) {
                return view('backend.admin.business.business_info')->with(['case' => $getCase[0], 'getBusinessInfo' => $getBusinessInfo]);
            } else if (Auth::user()->roles == 2) {
                return view('backend.team.business.business_info')->with(['case' => $getCase[0], 'getBusinessInfo' => $getBusinessInfo]);
            } else {
                return view('backend.staff.business.business_info')->with(['case' => $getCase[0], 'getBusinessInfo' => $getBusinessInfo]);
            }
        }
    }

    public function getProjectInfo($id)
    {
        $getCase = QgCase::with('notes')->where('case_id', $id)->get()->toArray();

        if(!empty($getCase[0]) && array_key_exists('0', $getCase)){
                if(!empty($getCase[0]['address'])){
                    $address = json_decode($getCase[0]['address'], true);

                    $getCase[0]['address1'] = '';
                    if($address['address1']){
                        $getCase[0]['address1'] = $address['address1'];
                    }

                    $getCase[0]['address2'] = '';
                    if($address['address2']){
                        $getCase[0]['address2'] = $address['address2'];
                    }

                    $getCase[0]['town_or_city'] = '';
                    if($address['town_or_city']){
                        $getCase[0]['town_or_city'] = $address['town_or_city'];
                    }

                    $getCase[0]['country'] = '';
                    if($address['country']){
                        $getCase[0]['country'] = $address['country'];
                    }
                    
                    //dd($getCase);
                }
            }

        $getProjectInfo = ProjectInfo::with('services')->where('case_id', $id)->get()->toArray();

        if (Auth::user()->roles == 1) {
            return view('backend.admin.project_info.project_info')->with(['case' => $getCase[0], 'getProjectInfo' => $getProjectInfo]);
        } else if (Auth::user()->roles == 2) {
            return view('backend.team.project_info.project_info')->with(['case' => $getCase[0], 'getProjectInfo' => $getProjectInfo]);
        } else {
            return view('backend.staff.project_info.project_info')->with(['case' => $getCase[0], 'getProjectInfo' => $getProjectInfo]);
        }
    }

    public function getCompanyInfo($id)
    {
        $getCase = QgCase::with('notes')->where('case_id', $id)->get()->toArray();

        if(!empty($getCase[0]) && array_key_exists('0', $getCase)){
            if(!empty($getCase[0]['address'])){
                $address = json_decode($getCase[0]['address'], true);

                $getCase[0]['address1'] = '';
                if($address['address1']){
                    $getCase[0]['address1'] = $address['address1'];
                }

                $getCase[0]['address2'] = '';
                if($address['address2']){
                    $getCase[0]['address2'] = $address['address2'];
                }

                $getCase[0]['town_or_city'] = '';
                if($address['town_or_city']){
                    $getCase[0]['town_or_city'] = $address['town_or_city'];
                }

                $getCase[0]['country'] = '';
                if($address['country']){
                    $getCase[0]['country'] = $address['country'];
                }
                
                //dd($getCase);
            }
        }

        $getCompanyInfo = CompanyInfo::where('case_id', $id)->get()->toArray();

        if (count($getCompanyInfo) > 0) {

            if (Auth::user()->roles == 1) {
                return view('backend.admin.company.company_info')->with(['case' => $getCase[0], 'getCompanyInfo' => $getCompanyInfo[0]]);
            } else if (Auth::user()->roles == 2) {
                return view('backend.team.company.company_info')->with(['case' => $getCase[0], 'getCompanyInfo' => $getCompanyInfo[0]]);
            } else {
                return view('backend.staff.company.company_info')->with(['case' => $getCase[0], 'getCompanyInfo' => $getCompanyInfo[0]]);
            }
        } else {
            if (Auth::user()->roles == 1) {
                return view('backend.admin.company.company_info')->with(['case' => $getCase[0], 'getCompanyInfo' => []]);
            } else if (Auth::user()->roles == 2) {
                return view('backend.team.company.company_info')->with(['case' => $getCase[0], 'getCompanyInfo' => []]);
            } else {
                return view('backend.staff.company.company_info')->with(['case' => $getCase[0], 'getCompanyInfo' => []]);
            }
        }
    }

    public function updateSidenote(Request $request, $id)
    {
        if ($request->cliktype == 'sdneditfullname') {
            $query = [
                'first_name' => $request->fname,
                'last_name' => $request->lname
            ];
        }

        if ($request->cliktype == 'sdneditsalutation') {
            $query = [
                'saluation' => $request->salutation
            ];
        }

        if ($request->cliktype == 'sdneditemail') {
            $query = [
                'email' => $request->email
            ];

            $email = $request->email;

            $curl = curl_init();
            curl_setopt_array($curl, array(
                CURLOPT_URL => 'https://api.datasoap.co.uk/v2/',
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => '',
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => '{
                "lookup": "' . $email . '",
                "checks": [
                "Email"
                ]
                }',
                CURLOPT_HTTPHEADER => array(
                    'Authorization: Bearer 303dcd5897c14d0eb42f6101d800bd71eb02bc3883ba478eb6284d66c9ddd977',
                    'Content-Type: application/json'
                ),
            ));

            $response = curl_exec($curl);

            curl_close($curl);

            $resp = json_decode($response);

            if ($resp->valid != 1) {
                return response()->json(['status' => 'failed', 'message' => 'Email is not valid']);
            }
        }

        if ($request->cliktype == 'sdneditfullphon') {
            $query = [
                'mobile_no' => $request->phone
            ];

            $phone = $request->phone;

            $curl = curl_init();
            curl_setopt_array($curl, array(
                CURLOPT_URL => 'https://api.datasoap.co.uk/v2/',
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => '',
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => '{
                "lookup": "' . $phone . '",
                "checks": [
                "Hlr"
                ]
                }',
                CURLOPT_HTTPHEADER => array(
                    'Authorization: Bearer 303dcd5897c14d0eb42f6101d800bd71eb02bc3883ba478eb6284d66c9ddd977',
                    'Content-Type: application/json'
                ),
            ));

            $response = curl_exec($curl);

            curl_close($curl);

            $resp = json_decode($response);

            if ($resp->valid != 1) {
                return response()->json(['status' => 'failed', 'message' => 'Phone No is not valid']);
            }
        }

        if ($request->cliktype == 'sdneditfulldob') {
            $date = DateTime::createFromFormat('d/m/Y', $request->dob);
            $formattedDate = $date->format('Y-m-d');
            $query = [
                'dob' => $formattedDate
            ];
        }

        $updateSidenote = QgCase::where('case_id', $id)->update($query);

        if ($updateSidenote) {
            return response()->json(['status' => 'success', 'message' => 'Sidenote updated successfully']);
        } else {
            return response()->json(['status' => 'failed', 'Something went wrong']);
        }
    }
}
