<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\QgService;
use Illuminate\Http\Request;
use Exception;

class ServiceController extends Controller
{

    public function index()
    {
        $services = QgService::orderBy('id', 'desc')->get()->toArray();
        return view('backend.admin.services.services')->with(['data' => $services]);
    }

    public function addService(Request $request)
    {
        try {
            if ($request->isMethod('get')) {
                return view('backend.admin.services.add_service');
            } else {

                $validator = (new QgService)->validateService('add', $request->all());

                if ($validator->fails()) {
                    return redirect()->route('add-service')
                        ->withErrors($validator)
                        ->withInput();
                }

                $file = $request->file('icon');
                $filename = time() . '.' . $file->getClientOriginalExtension();
                $destinationPath = public_path('backend/assets/uploads/services');

                $file->move($destinationPath, $filename);

                $addService = QgService::create([
                    'name' => $request->name,
                    'icon' => $filename,
                    'key' => $request->key,
                    'alt_key' => $request->alt_key,
                    'description' => $request->description,
                    'status' => $request->status
                ]);

                if ($addService) {
                    return redirect()->route('admin-services');
                } else {
                    abort(404);
                }
            }

            return redirect()->route('admin-services')
                ->with('error', lang('common.something_wrong'));
        } catch (Exception $e) {
            return redirect()->route('admin-services')
                ->with('error', lang('messages.server_error'));
        }
    }

    public function editService(Request $request, $id)
    {
        try {
            if ($request->isMethod('get')) {
                $services = QgService::where('id', $id)->get()->toArray();
                return view('backend.admin.services.edit_service')->with(['data' => $services[0]]);
            } else {

                $validator = (new QgService)->validateService('edit', $request->all());

                if ($validator->fails()) {
                    return redirect()->route('edit_service', $id)
                        ->withErrors($validator)
                        ->withInput();
                }

                if ($request->hasFile('icon')) {
                    $file = $request->file('icon');
                    $filename = time() . '.' . $file->getClientOriginalExtension();
                    $destinationPath = public_path('backend/assets/uploads/services');

                    $file->move($destinationPath, $filename);

                    $editService = QgService::where('id', $id)->update([
                        'name' => $request->name,
                        'key' => $request->key,
                        'alt_key' => $request->alt_key,
                        'description' => $request->description,
                        'icon' => $filename,
                        'status' => $request->status
                    ]);
                } else {
                    $editService = QgService::where('id', $id)->update([
                        'name' => $request->name,
                        'key' => $request->key,
                        'alt_key' => $request->alt_key,
                        'description' => $request->description,
                        'status' => $request->status
                    ]);
                }

                if ($editService) {
                    return redirect()->route('admin-services');
                } else {
                    abort(404);
                }
            }

            return redirect()->route('admin-services')
                ->with('error', lang('common.something_wrong'));
        } catch (Exception $e) {
            return redirect()->route('admin-services')
                ->with('error', lang('messages.server_error'));
        }
    }

    public function deleteService($id)
    {
        QgService::where('id', $id)->delete();
        return redirect()->route('admin-services');
    }
}
