<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Exception;

class StaffController extends Controller
{
    public function index()
    {
        $staff = User::where('roles', 3)->orderBy('id', 'desc')->get()->toArray();
        return view('backend.team.staff.staff')->with(['staff' => $staff]); 
    }

    public function addStaff(Request $request)
    {
        try
        {
            $validator = (new User)->validateTeam($request->all());

                if ($validator->fails()) {
                    return redirect()->route('staff')
                    ->with('error', lang('messages.server_error'));
                }
                
                $addStaff = User::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'password' => Hash::make('12345678'),
                    'roles' => 3
                ]);

                if($addStaff)
                {
                    DB::table('staffs')->insert([
                        'team_id' => Auth::user()->id,
                        'user_id' => $addStaff->id,
                        'name' => $request->name,
                        'created_at' => now(),
                        'updated_at' => now()
                    ]);
                    return redirect()->route('staff');
                }
                else
                {
                    abort(404);
                }
                
        }
        catch(Exception $e)
        {
            return redirect()->route('staff')
            ->with('error', lang('messages.server_error'));
        }
    }

    public function editStaff(Request $request, $id)
    {
        try
        {
            $validator = (new User)->validateTeam($request->all());

                if ($validator->fails()) {
                    return redirect()->route('staff')
                    ->with('error', lang('messages.server_error'));
                }
                
                $editStaff = User::where('id', $id)->update([
                    'name' => $request->name,
                    'email' => $request->email,
                    'password' => Hash::make('12345678'),
                    'roles' => 3
                ]);

                if($editStaff)
                {
                    DB::table('staffs')->insert([
                        'team_id' => Auth::user()->id,
                        'user_id' => $id,
                        'name' => $request->name,
                        'updated_at' => now()
                    ]);
                    return redirect()->route('staff');
                }
                else
                {
                    abort(404);
                }
        }
        catch(Exception $e)
        {
            return redirect()->route('staff')
            ->with('error', lang('messages.server_error'));
        }
    }

    public function deleteStaff($id)
    {
        $deleteStaff = User::where('id', $id)->delete();

        if($deleteStaff)
        {
            return redirect()->route('staff');
        }
    }
}
