<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use Exception;

class TeamController extends Controller
{
    public function index()
    {
        $teams = User::where('roles', 2)->orderBy('id', 'desc')->get()->toArray();
        return view('backend.admin.teams.teams')->with(['teams' => $teams]);
    }

    public function addTeam(Request $request)
    {
        try {
            $validator = (new User)->validateTeam($request->all());

            if ($validator->fails()) {
                return redirect()->route('teams')
                    ->with('error', lang('messages.server_error'));
            }

            $addTeam = User::create([
                'name' => $request->name,
                'email' => $request->email,
                'password' => Hash::make('12345678'),
                'roles' => 2
            ]);

            if ($addTeam) {
                DB::table('teams')->insert([
                    'owner_id' => Auth::user()->id,
                    'user_id' => $addTeam->id,
                    'name' => $request->name,
                    'created_at' => now(),
                    'updated_at' => now()
                ]);
                return redirect()->route('teams');
            } else {
                abort(404);
            }
        } catch (Exception $e) {
            return redirect()->route('teams')
                ->with('error', lang('messages.server_error'));
        }
    }

    public function editTeam(Request $request, $id)
    {
        try {
            $validator = (new User)->validateTeam($request->all());

            if ($validator->fails()) {
                return redirect()->route('teams')
                    ->with('error', lang('messages.server_error'));
            }

            $editTeam = User::where('id', $id)->update([
                'name' => $request->name,
                'email' => $request->email,
                'password' => Hash::make('12345678'),
                'roles' => 2
            ]);

            if ($editTeam) {
                DB::table('teams')->where('owner_id', Auth::user()->id)->where('user_id', $id)->update([
                    'owner_id' => Auth::user()->id,
                    'user_id' => $id,
                    'name' => $request->name,
                    'updated_at' => now()
                ]);
                return redirect()->route('teams');
            } else {
                abort(404);
            }
        } catch (Exception $e) {
            return redirect()->route('teams')
                ->with('error', lang('messages.server_error'));
        }
    }

    public function deleteTeam($id)
    {
        $deleteTeam = User::where('id', $id)->delete();

        if ($deleteTeam) {
            return redirect()->route('teams');
        }
    }
}
