<?php

namespace App\Http\Controllers\frontend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Models\CaseService;
use App\Models\BusinessService;
use App\Models\QgService;
use App\Models\BusinessKey;
use App\Models\BusinessDesign;
use App\Models\QgProjectScope;
use App\Models\ClientInfo;
use App\Models\User;
use App\Rules\EmailCheckRule;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Route;


class DashboardController extends Controller
{
    public function index()
    {
        $loginauthid = (authUserId());
        $caseServices = DB::table('case_services')
                        ->where('user_id', $loginauthid)
                        ->get();
        $sidebarservices = DB::table('case_qg_services')->get();
        return view('frontend.pages.dashboard', compact('caseServices', 'sidebarservices'));

    }
    public function businessinformation($case_id)
    {
        $loginauthid = (authUserId());
        $caseServices = DB::table('case_services')
                        ->where('user_id', $loginauthid)
                        ->get();

        $sidebarservices = DB::table('case_qg_services')->get();

        $company_information = DB::table('case_company_information')->where('case_id', $case_id)->first();
        $industry_scope = "";

        $industry = DB::table('case_project_scope')
                            ->where('case_id', $case_id)
                            ->where('service_key', 'common')
                            ->where('response_key', 'bd_expanded')
                            ->first();

        // $industry_scope = unserialize($industry->business_scope);
        if(!empty($industry->business_scope) && isSerialized($industry->business_scope) ){
            $industry_scope = $industry ? unserialize($industry->business_scope) : null;
        }       

        
        $challenges = DB::table('case_project_scope')
                            ->where('case_id', $case_id)
                            ->where('service_key', 'common')
                            ->where('response_key', 'bc_expanded')
                            ->first();

        // $challenges_scope = unserialize($challenges->business_scope);
        $challenges_scope = $challenges ? unserialize($challenges->business_scope) : null;

        
        return view('frontend.pages.businessinformation',compact('caseServices', 'sidebarservices', 'company_information', 'industry_scope', 'challenges_scope'));

    }

    public function solutions($case_id,$service_id)
    {
        $route = Route::currentRouteName();
        $loginauthid = (authUserId());
        $caseServices = DB::table('case_services')
        ->where('user_id', $loginauthid)
        ->get();
        $sidebarservices = DB::table('case_qg_services')->get();


        /**************Projects Scope Data********/

        $caseExist = (new CaseService)->getCaseByCaseNumber($case_id);
        //dd($caseExist);
        if (!$caseExist) {
            return redirect()->route('funnel')
                ->with('error', lang('messages.invalid_id', string_manip(lang('case.case'))));
        }

        $projectScope = [
            'business_description' => '',
            'business_challenges' => '',
            'services' => [],            
            ];

        $caseServiceData = (new CaseService)->getServiceByCaseNumber($case_id);

      //  $businessService = (new BusinessService)->getExistServiceByCase($case_id);

        $businessService = (new BusinessService)->getExistServiceByCaseService($case_id, $service_id);

        $services = [];
        if(!empty($caseServiceData)){
            $caseExplode = explode(",",$caseServiceData);
            $services = (new QgService)->getAllByServiceIDs($caseExplode);
        }

        $serviceById = (new QgService)->getServiceByServiceID($service_id);


        $loader = false;

        if($caseExist){

            $data['scope'] = (new QgProjectScope)->getAllByCaseID($case_id);

            if(!empty($data['scope']) && $data['scope']->isNotEmpty()){
                //isEmpty
                //isNotEmpty

                $loader = true;                

                foreach ($data['scope'] as $spK => $spV) {

                    //dd($spV);
                    
                    if(!empty($spV->business_scope) && isSerialized($spV->business_scope)){

                        $scopeData = (array) unserialize($spV['business_scope']); 
                        
                        if(!empty($scopeData['bd_expanded']) && array_key_exists('bd_expanded', $scopeData) ){
                            $projectScope['business_description'] = $scopeData['bd_expanded'];
                        }

                        if(!empty($scopeData['bc_expanded']) && array_key_exists('bc_expanded', $scopeData) ){
                            $projectScope['business_challenges'] = $scopeData['bc_expanded'];
                        } 

                        if(!empty($scopeData['description_expanded']) && array_key_exists('description_expanded', $scopeData) ){

                            $projectScope['services'][$scopeData['key']]['description'] = $scopeData['description_expanded'];
                        }

                        if(!empty($scopeData['question_id']) && array_key_exists('question_id', $scopeData) && !empty($scopeData['response']) && array_key_exists('response', $scopeData) ){

                            $projectScope['services'][$scopeData['key']][$scopeData['question_id']] = $scopeData['response'];
                        }

                        /*echo "<pre>";
                        print_r($scopeData);
                        echo "</pre>";*/

                    }                    
                }
            }
        }

        /************Projcts Scope Data End********/
        return view('frontend.pages.solutions',compact('caseServices', 'sidebarservices', 'services', 'projectScope', 'serviceById', 'businessService','route'));

    }
    public function developersarea()
    {
        $loginauthid = (authUserId());
        $caseServices = DB::table('case_services')
                        ->where('user_id', $loginauthid)
                        ->get();
        $sidebarservices = DB::table('case_qg_services')->get();

        return view('frontend.pages.developersarea',compact('caseServices', 'sidebarservices'));

    }
    public function fileupload(Request $request)
    {
    	
	if($request->method('get') == "GET"){
	    $case_id = request('case_id');
	    $service_id = request('service_id');
	}else if($request->method('post') == "POST"){
	    //dd($request->all());    
	    $case_id = $request->input('case_id');
	    $service_id = $request->input('service_id');
	}  

	$request->validate([
	    'upload_file.*' => 'mimes:png,jpg,jpeg,pdf|max:5120',
	]);
	
	$caseExist = (new CaseService)->getCaseByCaseNumber($case_id);

	if(!empty($case_id) && empty($caseExist)){
	    return abort(404);
	}  
	
	$serviceExist = (new CaseService)->getServiceByServiceID($caseExist, $service_id);
	
	if(!empty($service_id) && empty($serviceExist)){
	    return abort(404);
	}     
	

       /* if(){
	    return abort(404);
	}*/

	$loginauthid = authUserId();
	$caseServices = DB::table('case_services')
	                ->where('user_id', $loginauthid)
	                ->get();

	// $serviceProject = DB::table('case_services')->join('projects', 'projects.case_id','=','case_services.case_id')->first(['projects.id','case_services.case_id']);
	 $serviceProject = DB::table('case_services')->join('projects', 'projects.case_id','=','case_services.case_id')->where('case_services.case_id', $case_id)->first(['projects.id as project_id','case_services.case_id as case_id']);
	$sidebarservices = DB::table('case_qg_services')->get();
	$files = $request->file('upload_file');
	$uploadedFiles = [];
	$errors = [];
      

	if ($files && !empty($serviceProject)) {

	    foreach ($files as $file) {

	        if ($file->isValid()) {


	            $fileSize = $file->getSize(); 
	            if ($fileSize > 5 * 1024 * 1024) { 
	                $errors[] = $file->getClientOriginalName() . ' is larger than 5 MB and will not be uploaded.';
	                continue;
	            }
	            $ongfilename = $file->getClientOriginalName();
	            $filename = time() . '_' . $file->getClientOriginalName();
	            $path = $file->move(public_path('frontend/project-files'), $filename);                     

	            $imagePath = public_path('frontend/project-files').'/'.$filename;                    
	            
	            //url('frontend/project-files/'.$filename)
	            if(file_exists($imagePath)){
	            	
	            	if(Storage::disk('public')->exists($filename)){
			    	// Get the file contents
			        $fileContents = Storage::disk('public')->get($filename);
			        
			        // Upload the image to S3
			        $awspath =  Storage::disk('s3')->put('projectfiles/' . $filename, $fileContents, 'public');
			    //    $url = Storage::disk('s3')->url($awspath);
			    //    echo $url;
			    //    exit;

			        Storage::disk('public')->delete($filename);

			        //$fileContents = Storage::disk('public')->get($filename);

			        DB::table('project_files')->insert([
			            'company_id' => 1,
			            'project_id' => $serviceProject->project_id,
			            'case_id' => $caseExist,
			            'service_id' => $service_id,
			            'user_id' => $loginauthid,
			            'filename' => $ongfilename,
			            'hashname' => $filename,
			            'size' => $fileSize, 
			            'added_by' => $loginauthid,
			            'created_at' => now(),
			            'updated_at' => now(), 
			        ]);
	            	}else{
	            		return response()->json(['errors' => ['File not found!']], 400);
	            	}
	                

	            }                   

	            
	        }
	    }

	    if (!empty($errors)) {
	        return response()->json(['errors' => $errors], 400);
	    }
	}
	$img_db = DB::table('project_files')
	            //->where('user_id', $loginauthid)
	            ->where('case_id', $case_id)
	            ->where('service_id', $service_id)
	            ->get();

	//dd($img_db);

	$route = Route::currentRouteName();
	
	return view('frontend.pages.fileupload', compact('caseServices', 'sidebarservices', 'img_db', 'caseExist','service_id', 'route'));
		
    	      
        
    }

    public function downloadFile($filename)
    {
        // Check if file exists in S3
        if (Storage::disk('s3')->exists('projectfiles/' . $filename)) {
            $file = Storage::disk('s3')->get('projectfiles/' . $filename);
            $mimeType = Storage::disk('s3')->mimeType('projectfiles/' . $filename);

            return response($file, Response::HTTP_OK)
                ->header('Content-Type', $mimeType)
                ->header('Content-Disposition', 'attachment; filename="'.$filename.'"');
        }

        // If file does not exist, return a 404 error
        abort(404, 'File not found.');
    }

    public function liveupdate()
    {
        return view('frontend.pages.liveupdate');

    }
    public function profile()
    {
        $loginauthid = (authUserId());
        $caseServices = DB::table('case_services')
                        ->where('user_id', $loginauthid)
                        ->get();
        $sidebarservices = DB::table('case_qg_services')->where('status', 1)->get();

        $profile = DB::table('users')->where('id', $loginauthid)->first();  

        //dd($profile);      

        return view('frontend.pages.profile', compact('caseServices', 'sidebarservices', 'profile'));

    }
    public function editprofile()
    {
        $loginauthid = authUserId();
        $caseServices = DB::table('case_services')
                        ->where('user_id', $loginauthid)
                        ->get();
        $sidebarservices = DB::table('case_qg_services')->where('status', 1)->get();
        
        $profile = DB::table('users')->where('id', $loginauthid)->first();

        $mobileExplode = [];
        $mobile = '';
        if(!empty($profile->mobile)){
            $mobileExplode = explode("+44", $profile->mobile);
            if(!empty($mobileExplode) && array_key_exists(1, $mobileExplode)){
                $mobile = $mobileExplode[1];            
            }
        }

        //dd($profile);           

        return view('frontend.pages.editprofile', compact('caseServices', 'sidebarservices', 'profile', 'mobile'));

    }

    public function profileupdate(Request $request)
    {
        $inputs = $request->all();
        try {
            unset($inputs['_token']);

            $inputs['mobile_number'] = '+44'.$inputs['mobile_number'];

            $validator = (new User)->editValidate($inputs);
                
            if ($validator->fails()) {
                //dd($validator->errors());
                return redirect()->route('editprofile')
                    ->withInput()
                    ->withErrors($validator);
            }

            $dob = $inputs['day'].'-'.$inputs['month'].'-'.$inputs['year'];
            $dob = dateFormat('Y-m-d',$dob);

            $profileData = [
                'mobile' => $inputs['mobile_number'],
                'dob' =>  $dob,
                'communicate_email' => $inputs['email'],
                'updated_at' => currentDate(true),
            ];

            //dd($profileData);

            (new User)->updateProfile($profileData, authUserId());

            return redirect()->route('editprofile')->with('success', 'Profile updated successfully.');

        } catch (\Exception $e) {
            //dd($e->getMessage());
            //DB::rollBack();
            //dd($e->getMessage());
            return redirect()->route('editprofile')->with('error', lang('messages.server_error'));            

        }

    }
}
