<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Rules\WordCountRule;

class BusinessInfo extends Model
{
    use HasFactory;

    public $table = 'case_business_info';

    protected $fillable = [
        'case_id',
        'guest_id',
        'user_id',
        'about_business',
        'business_challenges'
    ];
    public function getAll(){
        return $this->get()->toArray();
    }

    /*public function getDetailsByIds($search){
        $fields = ['id','name'];        
        return $this->whereIn('id',$search)->get($fields)->toArray();
    }*/

    /*public function validate($data){
        $validated = $data->validate([
            'title' => 'required|unique:posts|max:255',
            'body' => 'required',
        ]);
    }*/

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validate($inputs, $id = null)
    {
        $rules = [
            'business_info' => ['required','regex:/[a-zA-Z0-9\s]+/', new WordCountRule],
            'business_challenges' => ['required','regex:/[a-zA-Z0-9\s]+/', new WordCountRule],
        ];

        /*if($id) {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30||unique:package,name,' . $id . ',id,deleted_at,NULL'; 
            
        } else {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30|unique:package,name,NULL,id,deleted_at,NULL';            
        }*/

        $messages = array(
            'business_info.required' => 'The Business Information field is required.',
            /*'business_info.string' => 'The Business Information field needs to be string format.',*/
            /*'business_info.max' => 'The Business Information field can only be entered 1000 letters.',
*/
            'business_challenges.required' => 'The Business Challenges field is required.',
            /*'business_challenges.string' => 'The Business Challenges field needs to be string format.',*/
            /*'business_challenges.max' => 'The Business Challenges field can only be entered 1000 letters.',*/
            
            /*'business_info.string' => 'The Business Information field needs to be string format.',*/
            /*'business_info.max' => 'The Business Information field can only be entered 1000 letters.',*/
        );

        return \Validator::make($inputs, $rules, $messages);
    }

    public function backup_validate($inputs, $id = null)
    {
        $rules = [
            'business_info' => 'required|regex:/[a-zA-Z0-9\s]+/|max:1000',
            'business_challenges' => 'required|regex:/[a-zA-Z0-9\s]+/|max:1000',
            'service_desc.*' => 'required|regex:/[a-zA-Z0-9\s]+/|max:1000',  
            'already_service.*' => 'required',           
        ];


        
        /*if($id) {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30||unique:package,name,' . $id . ',id,deleted_at,NULL'; 
            
        } else {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30|unique:package,name,NULL,id,deleted_at,NULL';            
        }*/

        $messages = array(
            'business_info.required' => 'The Business Information field is required.',
            'business_info.string' => 'The Business Information field needs to be string format.',
            'business_info.max' => 'The Business Information field can only be entered 1000 letters.',

            'business_challenges.required' => 'The Business Challenges field is required.',
            'business_challenges.string' => 'The Business Challenges field needs to be string format.',
            'business_challenges.max' => 'The Business Challenges field can only be entered 1000 letters.',

            'service_desc.*.required' => 'The Business Information field is required.',
            'already_service.*.required' => 'The field is required.',
            'business_info.string' => 'The Business Information field needs to be string format.',
            'business_info.max' => 'The Business Information field can only be entered 1000 letters.',
        );

        return \Validator::make($inputs, $rules, $messages);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validateServiceType($inputs, $id = null)
    {
        $rules = [
            'already_service.*' => 'required',   
            'service_desc.*' => ['required','regex:/[a-zA-Z0-9\s]+/',new WordCountRule]
            //'service_desc.*' => 'required|regex:/[a-zA-Z0-9\s]+/|max:1000'        
        ];

        
        
        
        /*if($id) {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30||unique:package,name,' . $id . ',id,deleted_at,NULL'; 
            
        } else {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30|unique:package,name,NULL,id,deleted_at,NULL';            
        }*/

        $messages = array(
            'already_service.*.required' => 'The field is required.',
            'service_desc.*.required' => 'The Description field is required.',
        );

        return \Validator::make($inputs, $rules, $messages);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validateStage($inputs, $id = null)
    {
        $rules = [
            'business_functionality' => 'required|regex:/[a-zA-Z0-9\s]+/|max:1000',                        
        ];

        $messages = [
            'business_functionality.required' => 'The Key Functionality field is required.',
            'business_functionality.regex' => 'The Key Functionality field needs to be string format.',
            'business_functionality.max' => 'The Key Functionality field can only be entered 1000 letters.',
        ];

        //dd($inputs);       
        

        $messages = $messages + [
        'business_keys.*.required' => 'The Key Stages field is required.',
        'business_keys.*.regex' => 'The Key Stages field needs to be string format.',  
        'business_keys.*.min' => 'The Key Stages field should be atleast 30 characters.',               
        ];
        
        if(array_key_exists('business_keys', $inputs) && empty($inputs['business_keys'])){
            
            /*$rules = $rules + [
                'business_keys.1' => ['required','regex:/[a-zA-Z0-9\s]+/',new WordCountRule("Key Stages")]
            ];  */

            $rules = $rules + [
                'business_keys.1' => ['required','regex:/[a-zA-Z0-9\s]+/','min:30']
            ];         
            
            
        }else{

             $rules = $rules + [
            'business_keys.*' => ['required','regex:/[a-zA-Z0-9\s]+/','min:30'],
            ];

        }        

        if(!array_key_exists('expect_design', $inputs)){
            $rules = $rules + [
                'website_envision' => 'required|regex:/[a-zA-Z0-9\s]+/|max:1000',
            ];

            $messages = $messages + [
                
                'website_envision.required' => 'The Envision field is required.',
                'website_envision.regex' => 'The Envision field needs to be string format.',
                'website_envision.max' => 'The Envision field can only be entered 1000 letters.',                
            ];

        }

        //dd($inputs);  

        return \Validator::make($inputs, $rules, $messages);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function store($inputs, $id = null)
    {
        if ($id) {
            $this->find($id)->update($inputs);
            return $id;
        } else {
            return $this->create($inputs)->id;
        }
    }

    public function deleteByCaseID($case_id){
        return $this->where('case_id', $case_id)->delete();
    }
}
