<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Rules\MobileCheckRule;
use App\Rules\EmailCheckRule;

class ClientInfo extends Model
{
    use HasFactory;

    public $table = 'case_client_information';

    protected $fillable = [
        'case_id',
        'guest_id',
        'user_id',
        'saluation',
        'first_name',
        'last_name',
        'dob',
        'postal_code',
        'address',
        'mobile_no',
        'email',
        'agree_communication',
        'created_at'
    ];
    public function getAll(){
        return $this->get()->toArray();
    }

    /*public function getDetailsByIds($search){
        $fields = ['id','name'];        
        return $this->whereIn('id',$search)->get($fields)->toArray();
    }*/

    /*public function validate($data){
        $validated = $data->validate([
            'title' => 'required|unique:posts|max:255',
            'body' => 'required',
        ]);
    }*/

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validate($inputs, $id = null)
    {
        $messages = [];
        $rules = [
            'salutation' => 'required|string|max:4',            
            'first_name' => 'required|string|min:3|max:20',
            'last_name' => 'required|string|min:3|max:20', 
            'day' => 'required|numeric|digits_between:1,2', 
            'month' => 'required|numeric|digits_between:1,2',
            'year' => 'required|numeric|digits_between:1,4',
            'client_data' => 'required',
            'mobile_number' => ['required',new MobileCheckRule],
            'email' => ['required','string', 'email' ,new EmailCheckRule], 
            'agree' => 'required|numeric',        
        ];

         $messages = array(
            'client_data.required' => 'The Current Address field is required.',                         
        );       

        return \Validator::make($inputs, $rules, $messages);
    } 


    public function getClientInfoByCaseID($case_id){

        $data = $this->where('case_id', $case_id)->first();
        if(!empty($data)){
           return $data; 
        }
        return null;
    } 


    

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function storeMultiple($inputs)
    {        
        return $this->insert($inputs);        
    } 

      

}
