<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class CompanyInfo extends Model
{
    use HasFactory;

    public $table = 'case_company_information';

    protected $fillable = [
        'case_id',
        'guest_id',
        'user_id',
        'company_number',        
        'is_registered',
        'company_details',
        'is_domain',
        'domain_name',
        'created_at'
    ];
    public function getAll(){
        return $this->get()->toArray();
    }

    /*public function getDetailsByIds($search){
        $fields = ['id','name'];        
        return $this->whereIn('id',$search)->get($fields)->toArray();
    }*/

    /*public function validate($data){
        $validated = $data->validate([
            'title' => 'required|unique:posts|max:255',
            'body' => 'required',
        ]);
    }*/

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validate($inputs, $id = null)
    {
        $rules = [
            'is_registered' => 'required|numeric',            
            'is_domain' => 'required|numeric', 
        ];        

        if($inputs['is_registered']){
            $rules = $rules + [
                'company_details' => 'required|string|max:200',
                'company_data' => 'required', 
                'company_number' => 'required',
            ];          
        }
        //regex:^(https?:\/\/)?(www\.)?[a-z0-9]+\.[a-z0-9]{2,3}$
        if($inputs['is_domain']){
            $rules = $rules + ['domain_name' => 'required|regex:/^[a-z0-9]+\.[a-z0-9]{2,3}$/|max:100'];          
        }  

        $messages = array(
            'is_registered.required' => 'The Is Company Registered field is required.',
            'is_registered.numeric' => 'The Is Company Registered field is invalid.',

            'company_data.required' => 'The Company Selection from list field is required.',
            'company_number.required' => 'The Company Selection from list field is required.',
            
            'is_domain.required' => 'The Is Domain Registered field is required.',
            'is_domain.numeric' => 'The Is Domain Registered field is invalid.',

            'domain_name.required' => 'The Domain Name field is required.',
            'domain_name.max' => 'The Domain Name field can only be entered 100 letters.',
            'domain_name.regex' => 'The Domain Name field is invalid.',                    
        );

        return \Validator::make($inputs, $rules, $messages);
    }    

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function storeMultiple($inputs)
    {        
        return $this->insert($inputs);        
    }
}
