<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

class Discussion extends Model
{
    use HasFactory;

    public $table = 'discussions';

    protected $guarded = ['id'];

    protected $fillable = [
        'company_id',
        'discussion_category_id',
        'project_id',
        'case_id',
        'service_id',
        'title',
        'description',
        'color',
        'user_id',
        'pinned',
        'closed',
        'deleted_at',
        'last_reply_at',
        'best_answer_id',
        'last_reply_by_id',
        'added_by',
        'last_updated_by',
        'created_at',
        'updated_at',
    ];    


    public function getAllQuestionByCaseService($case_id, $service_id){

        //\DB::enableQueryLog();
        $fields = [
                'discussions.id',
                'discussions.project_id',
                'discussions.service_id',
                'discussions.case_id',
                'discussions.title',
                'discussions.description',
                'discussions.last_reply_at',
                'discussions.created_at',
                'users.name as user_name',   
                //'role_user.role_id',                            
                ];

        $data = $this->join('users', 'users.id', '=', 'discussions.added_by')
                    //->with(['replies'])
                    ->with(['replies.user.role'])
                    ->where('discussions.case_id', $case_id)
                    ->where('discussions.service_id', $service_id)
                    //->groupBy('discussions.id')
                    ->get($fields); 
                    
        //dd($data->toArray());

        /*foreach($data as $k => $v){
            //dd($v->replies);
            foreach($v->replies as $kk => $vv){
                dd($vv->user);
            }
            
        } */
        
        /*$result = \DB::getQueryLog();
        dd($result);     */

        if($data->isNotEmpty()){
           return $data; 
        }

        return null;         
        
    }

    public function getDiscussionByID($discussion_id){

        $data = $this->where('id', $discussion_id)->first(['id']);
        if(!empty($data->id)){
           return $data->id; 
        }

        return null;         
        
    } 

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validateQuestions($inputs, $id = null)
    {
        $rules = [];
        $messages = [];

        if(array_key_exists('questions', $inputs) && empty($inputs['questions'])){
            $rules = $rules + [
                'questions.1' => ['required','regex:/[a-zA-Z0-9\s]+/','min:20','max:60']
            ];         
            
            
        }else{

             $rules = $rules + [
            'questions.*' => ['regex:/[a-zA-Z0-9\s]+/','min:20','max:60'],
            ];

        }

        $messages = $messages + [
            'questions.1.required' => 'The field is required.',
            'questions.*.regex' => 'The field needs to be string format.',  
            'questions.*.min' => 'The field should be atleast 20 characters.', 
            'questions.*.max' => 'The field should not be greater 60 characters.',                 
        ];        

        return \Validator::make($inputs, $rules, $messages);
    }


    public function replies(): HasMany
    {
        return $this->hasMany(DiscussionReply::class, 'discussion_id');
    } 

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class, 'user_id');
    }  

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function store($inputs, $id = null)
    {
        if ($id) {
            $this->find($id)->update($inputs);
            return $id;
        } else {
            return $this->create($inputs)->id;
        }
    }      

}
