<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Models\RoleUser;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

class DiscussionReply extends Model
{
    use HasFactory;

    public $table = 'discussion_replies';

    protected $guarded = ['id'];

    protected $fillable = [
        'company_id',
        'discussion_id',
        'user_id',
        'body',
        'deleted_at',
        'created_at',
        'updated_at',        
    ]; 

    public function discussion(): BelongsTo
    {
        return $this->belongsTo(Discussion::class);
    }

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class, 'user_id');
    } 

   /* public function user_role(): BelongsTo
    {
        return $this->belongsTo(RoleUser::class, 'user_id');
    } */ 

    public function validate($inputs, $id = null)
    {
        $rules = [
            'discussion_text' => 'required|regex:/[a-zA-Z0-9\s]+/|max:200',
        ];      

        return \Validator::make($inputs, $rules);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function store($inputs, $id = null)
    {
        if ($id) {
            $this->find($id)->update($inputs);
            return $id;
        } else {
            return $this->create($inputs)->id;
        }
    } 

    public function getReplyByID($reply_id){

        $data = $this->where('id', $reply_id)->first(['discussion_id','body','created_at']);
        if(!empty($data)){
           return $data; 
        }

        return [];         
        
    }     
    

}
