<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Rules\WordCountRule;


class ProjectInfo extends Model
{
    use HasFactory;

    public $table = 'case_project_information';

    protected $fillable = [
        'case_id',
        'guest_id',
        'user_id',
        'is_automated',
        'automated_parts',
        'is_api',
        'api_integration',
        'is_nda',

    ];
    public function getAll()
    {
        return $this->get()->toArray();
    }

    /*public function getDetailsByIds($search){
        $fields = ['id','name'];        
        return $this->whereIn('id',$search)->get($fields)->toArray();
    }*/

    /*public function validate($data){
        $validated = $data->validate([
            'title' => 'required|unique:posts|max:255',
            'body' => 'required',
        ]);
    }*/

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validate($inputs, $id = null)
    {
        $rules = [
            'is_automated' => 'required|numeric',            
            'is_api' => 'required|numeric',            
            'is_nda' => 'required|numeric',
        ];

        if(array_key_exists('is_automated', $inputs) && $inputs['is_automated'] == 1){
            $rules = $rules + ['automated_workflow' => ['required','regex:/[a-zA-Z0-9\s]+/',new WordCountRule]]; 
        }

        if(array_key_exists('is_api', $inputs) && $inputs['is_api'] == 1){
            $rules = $rules + ['api_integration' => ['required','regex:/[a-zA-Z0-9\s]+/',new WordCountRule]];                   
        }
        //dd($inputs);       

        $messages = array(
            'is_automated.required' => 'The Part of Your Workflow field is required.',
            'is_automated.numeric' => 'The Part of Your Workflow field is invalid.',

            'automated_workflow.required' => 'The Part of Your Workflow field is required.',

            'is_api.required' => 'The API integrations field is required.',
            'is_api.numeric' => 'The API integrations field is invalid.',

            'api_integration.required' => 'The API integrations field is required.',            

            'is_nda.required' => 'The NDA field is required.',
            'is_nda.numeric' => 'The NDA field is invalid.',
        );

        return \Validator::make($inputs, $rules, $messages);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function storeMultiple($inputs)
    {
        return $this->insert($inputs);
    }

    public function services()
    {
        return $this->hasOne(QgService::class, 'id');
    }

    public function deleteByCaseID($case_id){
        return $this->where('case_id', $case_id)->delete();
    }
}
