<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class ProjectOverview extends Model
{
    use HasFactory;

    public $table = 'case_short_project_overview';

    protected $fillable = [
        'flow_id',
        'guest_id',
        'user_id',
        'title',
        'ai_overview',
        'category',
        'skills',
        'scope',
        'created_at',
        'updated_at'       
    ]; 

    public function checkCaseByCaseNumber($case_number){

        $data = $this->where('flow_id', $case_number)->first(['flow_id']);
        if(!empty($data->flow_id)){
           return $data->flow_id; 
        }
        return null;
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validate($inputs, $id = null)
    {
        if($inputs['type'] == "title"){
            $rules = [
                'input' => ['required','regex:/[a-zA-Z0-9\s]+/','min:10','max:160'],
            ];
        }else if($inputs['type'] == "ai_overview"){
            $rules = [
                'input' => ['required','regex:/[a-zA-Z0-9\s]+/','min:160','max:500'],
            ];
        }else if($inputs['type'] == "category"){
            $rules = [
                'input' => ['required','regex:/[a-zA-Z0-9\s]+/','min:3','max:50'],
            ];
        }

        return \Validator::make($inputs, $rules);
    }

    

    public function getProjectOverviewById($flow_id){

        $data = $this->where('flow_id', $flow_id)->first(['id','flow_id','title',
        'ai_overview',
        'category',
        'skills',
        'scope'
            ]
        );
        
        if(!empty($data)){
           return $data; 
        }
        return null;
    }     

    /**
     * @param array $inputs
     * @param int $case_id
     *
     * @return mixed
     */
    public function updateProjectOverview($inputs, $case_id)
    {
        $this->where('flow_id', $case_id)->update($inputs);            
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function store($inputs, $id = null)
    {
        if ($id) {
            $this->find($id)->update($inputs);
            return $id;
        } else {
            return $this->create($inputs)->id;
        }
    }
      
}
