<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class QgService extends Model
{
    use HasFactory;

    public $table = 'case_qg_services';

    protected $fillable = [
        'name',
        'icon',
        'description',
        'key',
        'alt_key',
        'status'
    ];
    public function getAll()
    {
        return QgService::get()->toArray();
    }

    //Multiple ids input
    public function getAllByServiceIDs($services_ids)
    {
        return QgService::whereIn('id', $services_ids)->where('status', 1)->get(['id', 'key', 'name','alt_key']);
    }

     //Multiple ids input
     public function getServiceByServiceID($services_id)
     {
         return QgService::where('id', $services_id)->where('status', 1)->first();
     }

    public function getDetailsByIds($search)
    {
        $fields = ['id', 'name'];
        return $this->whereIn('id', $search)->get($fields)->toArray();
    }

    /*public function validate($data){
        $validated = $data->validate([
            'title' => 'required|unique:posts|max:255',
            'body' => 'required',
        ]);
    }*/

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validate($inputs, $id = null)
    {
        $rules = [
            'number_days' => 'required|numeric|max:365',
            'amount' => 'required|numeric'
        ];

        if ($id) {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30||unique:package,name,' . $id . ',id,deleted_at,NULL';
        } else {
            $rules['name'] = 'required|regex:/[a-zA-Z0-9\s]+/|max:30|unique:package,name,NULL,id,deleted_at,NULL';
        }

        return \Validator::make($inputs, $rules);
    }

    public function validateService($operation, $inputs)
    {

        if ($operation == 'add') {
            $rules = [
                'name' => 'required|regex:/[a-zA-Z0-9\s]+/|max:100',
                'description' => 'required|regex:/[a-zA-Z0-9\s]+/|max:500',
                'icon' => 'required|image|mimes:png|max:1024|dimensions:width=40,height=40',
                'key' => 'required|string',
                'alt_key' => 'required|string',
                'status' => 'required|integer'
            ];

            $messages = [
                'icon.dimensions' => 'The icon must be exactly 40x40 pixels.',
                'alt_key' => 'The additional key is required'
            ];

            return \Validator::make($inputs, $rules, $messages);
        } else {
            $rules = [
                'name' => 'required|regex:/[a-zA-Z0-9\s]+/|max:100',
                'description' => 'required|regex:/[a-zA-Z0-9\s]+/|max:500',
                'icon' => 'image|mimes:png|max:1024|dimensions:width=40,height=40',
                'key' => 'required|string',
                'alt_key' => 'required|string',
                'status' => 'required|integer'
            ];

            $messages = [
                'alt_key' => 'The additional key is required'
            ];

            return \Validator::make($inputs, $rules);
        }
    }

    public function businessServices()
    {
        return $this->hasOne(BusinessService::class, 'service_id', 'id');
    }

    public function projectInfo()
    {
        return $this->belongsTo(ProjectInfo::class, 'service_id');
    }

    public function getQuestion()
    {
        return $this->hasMany(Question::class, 'service_id');
    }

    public function getServiceById($services_id){

        $data = $this->where('id', $services_id)->first(['id']);
        if(!empty($data->id)){
           return $data->id; 
        }
        return null;
    } 

}
