<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class ShortFunnel extends Model
{
    use HasFactory;

    public $table = 'case_short_funnel';

    protected $primaryKey = 'id';

    protected $fillable = [
        'id',
        'flow_id',
        'guest_id',
        'user_id',
        'term',
        'is_ai',
        'summarise',
        'created_at',
        'updated_at',
    ];
    public function getAll(){
        return $this->get()->toArray();
    }

    public function getAllQuestionsByFlowId($flow_id){

        $data = $this->join('discussions', 'discussions.case_id','=','case_short_funnel.flow_id')->where('flow_id', $flow_id)->get(['discussions.*']);
        
        if(!empty($data)){
           return $data; 
        }
        return null;
    } 

    /*public function getDetailsByIds($search){
        $fields = ['id','name'];        
        return $this->whereIn('id',$search)->get($fields)->toArray();
    }*/

    /*public function validate($data){
        $validated = $data->validate([
            'title' => 'required|unique:posts|max:255',
            'body' => 'required',
        ]);
    }*/

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validateStartProject($inputs, $id = null)
    {
        $rules = [
            'term' => ['required'],            
        ];    

        return \Validator::make($inputs, $rules);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validateAi($inputs, $id = null)
    {
        $rules = [
            'with_ai' => ['required'],            
        ];    

        return \Validator::make($inputs, $rules);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function validateIdea($inputs, $id = null)
    {
        $rules = [
            'your_idea' => 'required|regex:/[a-zA-Z0-9\s]+/|min:2|max:160',
        ];    

        return \Validator::make($inputs, $rules);
    }    
    

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function store($inputs, $id = null)
    {
        if ($id) {
            $this->find($id)->update($inputs);
            return $id;
        } else {
            return $this->create($inputs)->id;
        }
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function updateByFlowID($inputs, $id = null)
    {
        if ($id) {
            $this->where('flow_id', $id)->update($inputs);
            return $id;
        } else {
            return $this->create($inputs)->id;
        }
    }

    public function deleteByCaseID($case_id){
        return $this->where('case_id', $case_id)->delete();
    }

    public function checkFlowExist(){

        $fields = ['id'];
        $data = $this->orderBy('id', 'desc')->limit(1)->first($fields);        
        if(!empty($data)){
            return $data->id;
        }else{
            return null;
        }   

        //\DB::enableQueryLog();
        //$result = \DB::getQueryLog();
        //dd($result);     
        
    }

    public function getCheckFlowByID($flow_id){

        $fields = ['id'];
        $data = $this->where('flow_id', $flow_id)->first($fields);        
        if(!empty($data)){
            return $data->id;
        }else{
            return null;
        }   

        //\DB::enableQueryLog();
        //$result = \DB::getQueryLog();
        //dd($result);     
        
    }
}
