<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use App\Rules\MobileCheckRule;
use App\Rules\EmailCheckRule;
use App\Models\RoleUser;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

class User extends Authenticatable
{
    use HasFactory, Notifiable;

    public $table = 'users';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [
        'id'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = ['password', 'remember_token', 'created_at', 'updated_at', 'headers','location_details'];

    public $dates = ['created_at', 'updated_at', 'last_login', 'two_factor_expires_at'];

    protected $casts = [
        'created_at' => 'datetime',
        'updated_at' => 'datetime',
        'last_login' => 'datetime',
        'two_factor_expires_at  ' => 'array',
        //'salutation' => Salutation::class,
    ];    

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */

    protected $fillable = [
        'company_id',
        'name',
        'email',
        'mobile',
        'salutation',
        'first_name',
        'last_name',
        'dob',
        'communicate_email',
        'address',
        'password',
        'status',
        'last_login',
        'admin_approval',
        'headers',
        'register_ip',
        'remember_token',
        'created_at',
        'updated_at',
    ];    

    public function validate($inputs)
    {
        $rules = [
            'name' => 'required|string|min:2|max:60',
            'email' => 'required|email|max:100|unique:users,email',
            'password' => 'required|string|min:8',
        ];

        $messages = array(
            'email.exists' => 'The email is already exists.',
                                
        );

        return \Validator::make($inputs, $rules, $messages);
    }

    public function validateConfirm($inputs)
    {
        $rules = [
            'email' => 'required|email|max:100|unique:users,email',
            'password' => 'required|string|min:8',
            'confirm_password' => 'required|string|min:8|same:password'           
        ];

        $messages = array(
            'email.exists' => 'The email is already exists.',
                                
        );

        return \Validator::make($inputs, $rules, $messages);
    }

    public function getNameSalutationAttribute()
    {
        return ($this->salutation ? $this->salutation->label() . ' ' : '') . $this->name;
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return \Illuminate\Validation\Validator
     */
    public function editValidate($inputs, $id = null)
    {
        $messages = [];
        $rules = [
            'day' => 'required|numeric|digits_between:1,2', 
            'month' => 'required|numeric|digits_between:1,2',
            'year' => 'required|numeric|digits_between:1,4',
            'mobile_number' => ['required',new MobileCheckRule],
            'email' => ['required','string', 'email' ,new EmailCheckRule], 
        ];       

        return \Validator::make($inputs, $rules, $messages);
    }


    public function validateLogin($inputs)
    {
        $rules = [
            'email' => 'required|email|max:100|exists:users,email',
            'password' => 'required|string|min:8',
        ];

        /*$messages = array(
            'email.exists' => 'The email is already exists.',
                                
        );*/

        return \Validator::make($inputs, $rules);
    }

    /**
     * @param array $inputs
     * @param int $id
     *
     * @return mixed
     */
    public function updateProfile($inputs, $user_id)
    {
        $this->where('id', $user_id)->update($inputs);
    } 

    public function role(): BelongsTo
    {
        return $this->belongsTo(RoleUser::class, 'user_id');
    }   
}
