@extends('frontend.layouts.master')
@section('style')

<script src="https://cdn.jsdelivr.net/npm/signature_pad@2.3.2/dist/signature_pad.min.js"> </script>

@endsection

@section('content')

<section class="main-content">
    <div class="step1 ndaagreement">
        <h1 class="mb-3 heading">Non-Disclosure Agreement (NDA)</h1>
        <h2 class="subheading mb-4">QwikGig prioritises the confidentiality of our clients and partners.</h2>

        <p class="d-flex align-items-start mt-3 nda-details"> 
            This NDA is a joint agreement to keep all shared information hereafter private and secure. This agreement protects both parties' interests and ensures that any disclosed ideas, strategies, or business plans remain confidential.
        </p>
        <p class="d-flex align-items-start mt-4 nda-details mb-4"> 
            Please review the NDA document carefully and sign below to acknowledge your acceptance.
        </p>
        
        
        <div class="filedetls bg-white px-md-4 p-3 mb-4 d-flex flex-column flex-sm-row align-items-sm-center align-items-start flex-wrap justify-content-between ">
            <div class="d-flex align-items-center">
                <div class="position-relative">
                    <span class="filetype pdf">PDF</span>
                    <img src="{{asset('frontend/assets/images/file.png')}}" alt="file">
                </div>
                <div class="ms-4">
                    <p class="filename mb-1">QwikGig_NDA.pdf</p>
                    <p class="filesize">1.5MB</p>
                </div>
            </div>
            <div class="btndiv">
                {{--
                <button class="fileremove me-3 border-0"> <i class="fa-solid fa-trash-can"></i> </button>
                <button class="filebtn filedownload me-3" data-index="0">Download</button>
                --}}
                <button class="filebtn fileview-transparent" data-index="0">View</button>
            </div>
        </div>

        <div class="d-flex justify-content-between mb-2 align-items-center">
            <p class="mb-0 signaturecnt">Signature</p>
             <!-- <button type="button" id="sig-clearBtn" class="clrbtn btn p-0 border-0" id="clear_button" style="font-weight: 500; color:#535AFF;"></button> -->
             <button type="button" class="btn p-0 border-0" id="clear_button" style="font-weight: 500; color:#121212;"><img src="{{ asset('frontend/assets/images/reset.svg') }}" class="me-1" alt="reset"> Reset</button>
            </div>

    
        <div class="signature-pad-container p-3 rounded w-100 bg-light">
            <canvas id="signature_pad"></canvas>
        </div> 

        <form method="POST" action="{{route('submit-nda', ['flow_id' => $flow_id])}}" id="service-form" onsubmit="return validateForm()">
        @csrf

        <a class="btn btn-primary m-0 mt-2 d-none" id="finish_button">Finish</a>
 

        <input type="hidden" name="signature" required>
        <input type="hidden" name="flow_id" value="{{$flow_id}}">

        <p class="signaturecnt mb-0 mt-2">Signed Date: 18 September 2024</p>            
        
        @include('frontend.layouts.messages')

        <div class="main-content-steps">
            <div class="btndv-main text-end">
                <!-- <button class="prevbtn btn stpbtn">Previous</button> -->
                {{--<button class="nxtbtn btn stpbtn step1-btn ms-3" type="submit">Get Started Using AI</button>--}}
                <button class="nxtbtn btn stpbtn step1-btn" type="submit">Continue</button>

            </div>
            
        </div>

        </form>
    </div>
</section>

@endsection

@section('scripts')
<script type="text/javascript">    

    /*$('.services-label').click(function(){
       var service_checkbox = $(this).attr("for");      
    })*/
    $( document ).ready(function() {
        $("#service-form")[0].reset()
    });

function validateForm() {
    return true;
    formSelect = $('#service-form');  
    
    var inputCheckbox  = formSelect.find('input[type="checkbox"]');
    var envision_select =formSelect.find('#website_envision');
    //Showing all errors
    var error = false;

    var inputCheckMin = 0;
    $(inputCheckbox).each(function() {
        var inputName = $(this).attr('name');
        inputBox = inputName;
        
        var inputChecked = formSelect.find('input[name="'+inputName+'"]');
        
        if (inputChecked.is(':checked') === true) {
            inputCheckMin++;            
        }         

    });     

    if(inputCheckMin == 0){
        formSelect.find(".invalid-feedback").html("Please select atleast one service.").show();
        error = true;

    }else{
        formSelect.find(".invalid-feedback").html("").hide();
    }    

    if(error){
        return false;
    }
    
    // If all checks pass, return true to allow form submission
    return true;
}
   
</script>

<script>
document.addEventListener("DOMContentLoaded", function () {
    var canvas = document.querySelector("#signature_pad");
    var signaturePad = new SignaturePad(canvas, {
        minWidth: 2,
        maxWidth: 4,
        penColor: "#9C9C9C" // Set the pen color to blue (you can change it to any color)
    });

    function resizeCanvas() {
        var ratio = Math.max(window.devicePixelRatio || 1, 1);
        canvas.width = canvas.offsetWidth * ratio;
        canvas.height = canvas.offsetHeight * ratio;
        canvas.getContext("2d").scale(ratio, ratio);
        let storedData = signaturePad.toData();
        signaturePad.clear(); // otherwise isEmpty() might return incorrect value
        signaturePad.fromData(storedData);
    }

    window.addEventListener("resize", resizeCanvas);
    resizeCanvas();

    var clearButton = document.querySelector("#clear_button");
    clearButton.addEventListener("click", function () {
        signaturePad.clear();
        $('input[name="signature"]').val('');
    });

    var finishButton = document.querySelector("#finish_button");
    finishButton.addEventListener("click", function () {
        const $svgDataUrl = signaturePad.toDataURL("image/png");
        $('input[name="signature"]').val($svgDataUrl);
        $('input[name="signature"]').next('.invalid-feedback').hide();
         
        console.log($svgDataUrl);
    });

    canvas.addEventListener("pointerout", function () {
        if (!signaturePad.isEmpty()) {
            finishButton.click();
        }
    });

    // Optional: also handle mouseleave event
    canvas.addEventListener("mouseleave", function () {
        if (!signaturePad.isEmpty()) {
            finishButton.click();
            document.querySelector(".invalid-feedback").stystyle.display = 'none';

        }
    });
});
</script>

@endsection

