@extends('frontend.layouts.portal_master')
@section('style')
<style type="text/css">
    .alert-error-message{
        display: none;
        color: red;
        border: 1px solid red;
        padding: 5px;
    }
    .alert-success-message{
        display: none;
        color: green;
        border: 1px solid green;
        padding: 5px;
    }
</style>

@endsection


@section('content')
<div class="content">
    <h2 class="mb-3 mb-md-4"> File Upload </h2>
    <div class="alert-success-message"></div>
    <div class="alert-error-message"></div>
    <div class="d-md-flex align-items-start">
        <div class="inrsidebar uploadfile">
            <div class="uploadfile-inr bg-white">
                <h3>Upload Files</h3>
                <form id="uploadForm" enctype="multipart/form-data" method="POST" action="{{ route('fileupload.db') }}">
                    @csrf

                    <input type="hidden" name="case_id" value="{{$caseExist}}">
                    <input type="hidden" name="service_id" value="{{$service_id}}">

                    <input type="file" id="upload_file" name="upload_file[]" class="d-none" multiple>
                    <label for="upload_file" id="drop_zone" class="upload-label text-center d-flex align-items-center justify-content-center">
                        <div>
                            <h4>Drag or click to upload</h4>
                            <p>File format PNG, PDF, JPG with a maximum size of 5MB</p>
                        </div>
                    </label>
                </form>
                <!-- Progress bar -->
                <div class="progress mt-3 d-none" id="uploadProgressContainer">
                    <div id="uploadProgress" class="progress-bar" role="progressbar" style="width: 0%;" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100">0%</div>
                </div>
            </div>
            <button type="submit" class="inrsidebtn uploadbtn mt-3">Upload</button>
        </div>
        <div class="inrcontent ps-md-4 mt-md-0 mt-3">
            @php
            if (!empty($img_db) && count($img_db) > 0) {
            @endphp

            @foreach($img_db as $item)
            @php
// echo "<pre>";
//     print_r($item);
//     echo "</pre>";
//     exit;
                $originalfilename = $item->filename;
                $filename = $item->hashname;
                    $awspath = Storage::disk('s3')->url('projectfiles/' . $filename, 'public');
                    $extension = pathinfo($awspath, PATHINFO_EXTENSION);
                    
                       $fileSize = $item->size;
                        if ($fileSize >= 1048576) { 
                            $fileSizeFormatted = number_format($fileSize / 1048576, 2); 
                            $fileSizeUnit = 'MB';
                        } elseif ($fileSize >= 1024) { 
                            $fileSizeFormatted = number_format($fileSize / 1024, 2); 
                            $fileSizeUnit = 'KB';
                        } else {
                            $fileSizeFormatted = $fileSize; 
                            $fileSizeUnit = 'Bytes';
                        }
                        
                        // $parts = explode('_', $filename, 2); 
                        // $final_filename = $parts[1]; 

                @endphp
             
                <div class="filedetls bg-white px-4 py-3 mb-3 d-flex flex-column flex-sm-row align-items-sm-center align-items-start flex-wrap justify-content-between gap-3">
                    <div class="d-flex align-items-center">
                        <div class="position-relative">
                            <span class="filetype">{{$extension}}</span>
                            <img src="{{ $awspath }}" alt="Image" style="width: 100px; height: auto;">
                        </div>
                        <div class="ms-4">
                            <p class="filename mb-1">{{$originalfilename}}</p>
                            <p class="filesize">{{ $fileSizeFormatted }} {{ $fileSizeUnit }}</p>
                        </div>
                    </div>
                    <div class="d-flex gap-3">
                        <button class="filebtn filedownload" data-url="{{ route('files.download', ['filename' => basename($awspath)]) }}">Download</button>
                        <button class="filebtn fileview" data-url="{{ $awspath }}">View</button>
                    </div>
                </div>
         
        @endforeach

        @php
        } else {
            echo '<p>No images available</p>';
        }
@endphp
        </div>
    </div>
</div>
@endsection

@section('scripts')
<script>
        $(document).on('click', '.filedownload', function() {
        var $awspath = $(this).data('url');
        var a = document.createElement('a');
        a.href = $awspath;
        a.download = $awspath.substring($awspath.lastIndexOf('/') + 1);
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
    });

    $(document).on('click', '.fileview', function() {
        var $awspath = $(this).data('url');
        window.open($awspath, '_blank');
    });

    $(document).ready(function () {
    $('.uploadbtn').click(function (e) {
        e.preventDefault();
        var formData = new FormData($('#uploadForm')[0]);
        var files = $('#upload_file')[0].files;
        var valid = true;
        var maxSize = 5 * 1024 * 1024;
        var allowedFormats = ['png', 'pdf', 'jpg', 'jpeg'];

        // Check file size and format
        for (var i = 0; i < files.length; i++) {
            var file = files[i];
            var fileName = file.name;
            var fileSize = file.size;
            var fileExtension = fileName.split('.').pop().toLowerCase();

            if (fileSize > maxSize) {
                alert('File "' + fileName + '" is larger than 5 MB and will not be uploaded.');
                valid = false;
                break;
            }

            if (!allowedFormats.includes(fileExtension)) {
                alert('File format for "' + fileName + '" is not allowed. Please upload PNG, PDF, or JPG files.');
                valid = false;
                break;
            }
        }

        if (!valid) {
            return; 
        }
        $('#uploadProgressContainer').removeClass('d-none');

        $.ajax({
            url: '{{ route("fileupload.db") }}',
            type: 'POST',
            data: formData,
            contentType: false,
            processData: false,
            xhr: function() {
                var xhr = new XMLHttpRequest();
                xhr.upload.addEventListener('progress', function(e) {
                    if (e.lengthComputable) {
                        var percentComplete = (e.loaded / e.total) * 100;
                        $('#uploadProgress').css('width', percentComplete + '%').text(Math.round(percentComplete) + '%');
                    }
                });
                return xhr;
            },
            success: function (response) {
                //console.log(response);
                //alert('Files uploaded successfully');
                $(".alert-success-message").html("File uploaded successfully!!").show();
                $('#uploadProgressContainer').addClass('d-none');
                $('#uploadProgress').css('width', '0%').text('0%');
                setTimeout(function () {
                    $(".alert-success-message").hide();
                     location.reload();
                 }, 2500);
                
            },
            error: function (error) {
                console.error('Error uploading files:', error);
                $(".alert-error-message").html("File didn't upload!!" + error).show();

                setTimeout(function () {
                    $(".alert-error-message").hide();                     
                 }, 2500);
                
                //alert(JSON.stringify(error));
                //alert('Error uploading files');
                $('#uploadProgressContainer').addClass('d-none');
                $('#uploadProgress').css('width', '0%').text('0%');
            }
        });
    });
});

</script>
@endsection

